.. _userguide:

************
User's Guide
************

Welcome to our User guide.
For more details checkout the :ref:`reference`.

.. toctree::
   :maxdepth: 2

   ccsds
   packetfields
   fixedlength
   variablelength
   loadfile
   converters
   utils
